@@ -1,4 +1,5 @@
 #include <stdio.h>
+#include <stdlib.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
@@ -9,10 +10,11 @@
 #include "lists.h"
 #include "cfg.h"
 #include "global_vars.h"
+#include "../config.h"
 
 #define LCS_CONFIG_LINE	1024
 
-#define LCS_PARANUM	52
+#define LCS_PARANUM	63
 
 #define LCS_CONF_BIND_TO 6
 #define LCS_CONF_PORT	5
@@ -39,12 +41,29 @@
 #define LCS_CONF_PINGERHOSTNAME 46
 #define LCS_CONF_LINE_LOCKING 48
 #define LCS_CONF_SYSLOGCALLFROM 49
+#define LCS_CONF_LINE_MKLOG 57
+#define LCS_CONF_ISDNCALLERSLOG 58
+#define LCS_CONF_ADBTABLE 59
+#define LCS_CONF_ADBNAME 60
+#define LCS_CONF_ADBPHONE 61
+#define LCS_CONF_CALLERSLOG 62
 #define LCS_IPL_ALLOW	"allow"
 #define LCS_IPL_DENY	"deny"
 #define LCS_CONF_YES	"yes"
 #define LCS_CONF_NO	"no"
+
+#if HAVE_MYSQL
+#define LCS_CONF_DBHOST 52
+#define LCS_CONF_DBPORT 53
+#define LCS_CONF_DBUSER 54
+#define LCS_CONF_DBPASS 55
+#define LCS_CONF_DBNAME 56
+#endif
 char ip[16];
 char dumstr[500];
+char dbs[20];
+//unsigned short dbport;
+unsigned int dbport;
 char yesno[2][4] = { "no", "yes" };
 char *CT_KEYS[CT_NUM_KEYS] = { "netdev", "isdn", "file" }; // mapping of server->con_type
 #define LCS_NUM_LPTSTAT_TYPES	3
@@ -63,7 +82,10 @@ char *conf_params[LCS_PARANUM]
 	"addressbook_location", "lptstatus", "lptaddr", "lptline",
 	"line", "isdninfo", "allow_manually", "html_status", "pidfile",
 	"pinger_hostname", "con_down_timeout", "line_locking", "syslog_call_from",
-	"line_baud_up", "line_baud_down" };
+	"line_baud_up", "line_baud_down",
+	"db_hostname", "db_port", "db_user", "db_pass", "db_name",
+	"mklog", "isdn_callerslog", "addrbook_table", "addrbook_namecol", "addrbook_numcol",
+	"callerslog" };
 void *conf_addrs[LCS_PARANUM]; // runtime initialisation
 char *conf_formats[LCS_PARANUM]
     = { "%s", "%[^\n]s", "%[^\n]s", "%s", "%s", "%d", "%s",
@@ -76,7 +98,10 @@ char *conf_formats[LCS_PARANUM]
 	"%s", "%s", "%x", "%16s",
 	"%16s", "%255s", "%4s", "%s", "%s",
 	"%s", "%d", "%s", "%s",
-	"%d", "%d" };
+	"%d", "%d",
+	"%s", "%d", "%s", "%s", "%s",
+	"%4s", "%4s", "%s", "%s", "%s",
+	"%s" };
 	
 void config_set_conf_lineaddrs(struct line_t* line)
 {
@@ -138,6 +163,20 @@ void config_set_conf_addrs()
     conf_addrs[46] = dumstr; // pinger_hostname %s
     conf_addrs[48] = dumstr; // line_locking [yes|no]
 	conf_addrs[49] = dumstr; // syslog_call_from [yes/NO]
+//#if HAVE_MYSQL
+    conf_addrs[52] = dbs;  
+//    conf_addrs[53] = &server->db_port;
+    conf_addrs[53] = &dbport;
+    conf_addrs[54] = dbs;
+    conf_addrs[55] = dbs;
+    conf_addrs[56] = dbs;
+//#endif
+	conf_addrs[57] = dumstr; // mklog [yes/no]
+	conf_addrs[58] = dumstr; // isdn_callerslog [yes/no]
+	conf_addrs[59] = dumstr; //server->addrbook_table;
+	conf_addrs[60] = dumstr; //server->addrbook_namecol;
+	conf_addrs[61] = dumstr; //server->addrbook_numcol;
+	conf_addrs[62] = dumstr; // server->callerslog;
 }
 
 void config_load_linedefaults(struct line_t *line)
@@ -161,6 +200,7 @@ void config_load_linedefaults(struct line_t *line)
  line->line_locking = 1;
  line->baud_up = 64000;
  line->baud_down = 64000;
+ line->mklog = 1;
  strcpy(line->script_up, sup);
  strcpy(line->script_dn, sdn);
  strcpy(line->interface, ifac);
@@ -186,6 +226,12 @@ void config_load_defaults()
  server->day_pos = LCS_DAY_POS;
  server->time_pos = LCS_TIME_POS;
  server->lpt_status = 0;
+ server->isdn_callerslog = 0;
+ strcpy(server->passwd_file, "[automatic]");
+ server->callerslog = strdup("/var/log/isdn.caller.log");
+#if HAVE_MYSQL 
+ server->db_port = LCS_DB_PORT;
+#endif 
 // server->syslog_call_from = 0;
  // we don't preload server->script_shutdown
  // don't init magicpass! (currently not used, came from ver 1.x)
@@ -218,11 +264,17 @@ void dump_configs()
      if ( server->lpt_linename[0] )
          fprintf(stdout, "  - linename: %s\n", server->lpt_linename);
  }
- if ( server->html_status_pipe )
+ fprintf(stdout, "- isdn_callerslog: %s\n", yesno[(int)server->isdn_callerslog]);
+ if ( server->isdn_callerslog )
+	fprintf(stdout, "  - callerslog: %s\n", server->callerslog);
+ if ( server->isdn_callerslog && server->addrbook_table )
  {
-     fprintf(stdout, "- html_status: %s\n", server->html_status_pipe);
+ 	fprintf(stdout, "  - addrbook_table: %s\n", server->addrbook_table);
+ 	fprintf(stdout, "  - addrbook_namecol: %s\n", server->addrbook_namecol);
+ 	fprintf(stdout, "  - addrbook_numcol: %s\n", server->addrbook_numcol);
  }
- fprintf(stdout, "- syslog_call_from: %s\n", yesno[(int)server->syslog_call_from]);
+ if ( !server->isdn_callerslog )
+	 fprintf(stdout, "- syslog_call_from: %s\n", yesno[(int)server->syslog_call_from]);
  fprintf(stdout, "- filter_type: ");
  switch (server->ipl_type)
  {
@@ -243,6 +295,18 @@ void dump_configs()
       fprintf(stdout, "%15s\n", inet_ntoa(addr2));
       iplentry = (struct ipl_item_t*)iplentry->next;
  }
+#if HAVE_MYSQL
+ if (server->db_hostname[0])
+ {
+      fprintf(stdout, "- database config:\n");
+      fprintf(stdout, "  - Hostname: %s\n", server->db_hostname);
+      fprintf(stdout, "  - DB port: %d\n", server->db_port);
+      fprintf(stdout, "  - DB name: %s\n", server->db_name);
+      fprintf(stdout, "  - Username: %s\n", server->db_user);
+      fprintf(stdout, "  - Password: NOT SHOWN\n");
+ }
+#endif 
+
 #ifdef SHUTDOWN_OK
  if ( server->script_shutdown[0] )
  {
@@ -268,6 +332,7 @@ void dump_configs()
  while ( curline )
  {
     fprintf(stdout, "\nLINE [%d:%s]:\n", curline->id, curline->linename);
+	fprintf(stdout, " - mklog: %s\n", yesno[(int)curline->mklog]);
     fprintf(stdout, " - allow_manually: %s\n", yesno[(int)curline->allow_manually]);
     fprintf(stdout, " - interface: %s\n", curline->interface);
 	fprintf(stdout, " - line_baud_up: %d\n - line_baud_down: %d\n",
@@ -396,7 +461,24 @@ int read_config(int argc, char **argv)
 		else
 		    server->send_throughput = 1;
 		break;
-	    case LCS_CONF_PINGER:
+#if HAVE_MYSQL
+            case LCS_CONF_DBHOST:
+                strcpy(server->db_hostname, dbs);
+                break;
+            case LCS_CONF_DBPORT:
+                server->db_port = (unsigned short)dbport;
+                break;
+            case LCS_CONF_DBUSER:
+                strcpy(server->db_user, dbs);
+                break;
+            case LCS_CONF_DBPASS:
+                strcpy(server->db_pass, dbs);
+                break;
+            case LCS_CONF_DBNAME:
+                strcpy(server->db_name, dbs);
+                break;
+#endif	
+            case LCS_CONF_PINGER:
 	        if ( !strcasecmp(dumstr, LCS_CONF_YES) )
 		    curline->pinger = 1;
 		else
@@ -429,7 +511,7 @@ int read_config(int argc, char **argv)
 		break;
 	    case LCS_CONF_SHUTDOWN:
 #ifndef SHUTDOWN_OK
-	        fprintf(stdout, "\nChange srv_def.h and recompile to enable shutdown support.\n");
+	        fprintf(stdout, "\nShutdown support disabled. See linesrv-2.1/configure --help for details.\n");
 #endif
 	        break;
 	    case LCS_CONF_CON_TYPE:
@@ -459,10 +541,16 @@ int read_config(int argc, char **argv)
 		break;
 	    case LCS_CONF_ALLOWMANUALLY:
 	        if ( !strcasecmp(dumstr, LCS_CONF_YES) )
-		    curline->allow_manually = 1;
-		else
-		    curline->allow_manually = 0;
-		break;
+			    curline->allow_manually = 1;
+			else
+			    curline->allow_manually = 0;
+			break;
+		case LCS_CONF_LINE_MKLOG:
+	        if ( !strcasecmp(dumstr, LCS_CONF_YES) )
+			    curline->mklog = 1;
+			else
+			    curline->mklog = 0;
+			break;
 	    case LCS_CONF_LINE_LOCKING:
 	        if ( !strcasecmp(dumstr, LCS_CONF_YES) )
 		    curline->line_locking = 1;
@@ -475,12 +563,34 @@ int read_config(int argc, char **argv)
 	    case LCS_CONF_PIDFILE:
 		server->pidfile = strdup(dumstr);
 		break;
+		case LCS_CONF_ADBTABLE:
+			if ( server->addrbook_table ) free(server->addrbook_table);
+			server->addrbook_table = strdup(dumstr);
+			break;
+		case LCS_CONF_ADBNAME:
+			if ( server->addrbook_namecol ) free(server->addrbook_namecol);
+			server->addrbook_namecol = strdup(dumstr);
+			break;
+		case LCS_CONF_ADBPHONE:
+			if ( server->addrbook_numcol ) free(server->addrbook_numcol);
+			server->addrbook_numcol = strdup(dumstr);
+			break;
+		case LCS_CONF_CALLERSLOG:
+			if ( server->callerslog ) free(server->callerslog);
+			server->callerslog = strdup(dumstr);
+			break;
 		case LCS_CONF_SYSLOGCALLFROM:
 	        if ( !strcasecmp(dumstr, LCS_CONF_YES) )
 		    	server->syslog_call_from = 1;
 			else
 				server->syslog_call_from = 0;
 			break;
+		case LCS_CONF_ISDNCALLERSLOG:
+	        if ( !strcasecmp(dumstr, LCS_CONF_YES) )
+		    	server->isdn_callerslog = 1;
+			else
+				server->isdn_callerslog = 0;
+			break;
 	    case LCS_CONF_PINGERHOSTNAME:
 		curline->pinger_hostname = strdup(dumstr);
 		break;
